@@ -9,6 +9,7 @@ class TestBronze:
                  storage_silver, input_data_param_v1, input_data_param_v2, input_data_param_v3, mount_data_param,
                  colums_validate_merge_param, new_name, database, target, origin, colum_filter, value_filter,
                  colum_validate_data, value_validate_data, number_items_valide_v1, number_items_valide_v2):
+        self.spark = spark
         self.util = Util()
         self.colum_filter = colum_filter
         self.value_filter = value_filter
@@ -16,13 +17,13 @@ class TestBronze:
         self.value_validate_data = value_validate_data
         self.number_items_valide_v1 = number_items_valide_v1
         self.number_items_valide_v2 = number_items_valide_v2
-        self.delta_lake_v1 = Bronze(spark, storage_account_name, storage_account_access_key, storage_landing,
+        self.delta_lake_v1 = Bronze(self.spark, storage_account_name, storage_account_access_key, storage_landing,
                                     storage_bronze, storage_silver, input_data_param_v1, mount_data_param,
                                     colums_validate_merge_param, new_name, database, target, origin)
-        self.delta_lake_v2 = Bronze(spark, storage_account_name, storage_account_access_key, storage_landing,
+        self.delta_lake_v2 = Bronze(self.spark, storage_account_name, storage_account_access_key, storage_landing,
                                     storage_bronze, storage_silver, input_data_param_v2, mount_data_param,
                                     colums_validate_merge_param, new_name, database, target, origin)
-        self.delta_lake_v3 = Bronze(spark, storage_account_name, storage_account_access_key, storage_landing,
+        self.delta_lake_v3 = Bronze(self.spark, storage_account_name, storage_account_access_key, storage_landing,
                                     storage_bronze, storage_silver, input_data_param_v3, mount_data_param,
                                     colums_validate_merge_param, new_name, database, target, origin)
 
@@ -33,7 +34,7 @@ class TestBronze:
         self.delta_lake_v1.load_data_csv(self.delta_lake_v1.input_data)
         self.delta_lake_v1.initialize_config_storage()
         self.delta_lake_v1.merge()
-        df = self.spark.delta_lake_v1.sql("select * from {0}.{1}").format(self.delta_lake_v1.database,
+        df = self.delta_lake_v1.spark.sql("select * from {0}.{1}").format(self.delta_lake_v1.database,
                                                                           self.delta_lake_v1.table_name)
         assert df.count() == self.number_items_valide_v1
 
@@ -53,7 +54,7 @@ class TestBronze:
         self.delta_lake_v3.load_data_csv(self.delta_lake_v3.input_data)
         self.delta_lake_v3.initialize_config_storage()
         self.delta_lake_v3.merge()
-        df = self.spark.sql("select {0} From {1}.{2} where {3}={4}").format(self.colum_validate_data,
+        df = self.delta_lake_v3.spark.sql("select {0} From {1}.{2} where {3}={4}").format(self.colum_validate_data,
                                                                             self.delta_lake_v1.database,
                                                                             self.delta_lake_v1.table_name,
                                                                             self.colum_filter, self.value_filter)
